import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { useState, useEffect, useRef, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { htmlImgProps } from './types';
var BASE_CLASS = 'sui-AtomImage';
var BASE_CLASS_FIGURE = BASE_CLASS + "-figure";
var CLASS_PLACEHOLDER = BASE_CLASS_FIGURE + "--placeholder";
var CLASS_SKELETON = BASE_CLASS_FIGURE + "--skeleton";
var CLASS_IMAGE = BASE_CLASS + "-image";
var CLASS_SPINNER = BASE_CLASS + "-spinner";
var CLASS_ERROR = BASE_CLASS + "-error";
/* eslint-disable-next-line react/prop-types */

var Error = function Error(_ref) {
  var className = _ref.className,
      Icon = _ref.icon,
      text = _ref.text;
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, Icon, /*#__PURE__*/React.createElement("p", null, text));
};

var AtomImage = function AtomImage(_ref2) {
  var placeholder = _ref2.placeholder,
      skeleton = _ref2.skeleton,
      bgStyles = _ref2.bgStyles,
      Spinner = _ref2.spinner,
      errorIcon = _ref2.errorIcon,
      errorText = _ref2.errorText,
      onError = _ref2.onError,
      onLoad = _ref2.onLoad,
      imgProps = _objectWithoutPropertiesLoose(_ref2, ["placeholder", "skeleton", "bgStyles", "spinner", "errorIcon", "errorText", "onError", "onLoad"]);

  var _useState = useState(true),
      loading = _useState[0],
      setLoading = _useState[1];

  var _useState2 = useState(false),
      error = _useState2[0],
      setError = _useState2[1];

  var imageRef = useRef();
  var handleLoad = useCallback(function () {
    setLoading(false);
    onLoad && onLoad();
  }, [onLoad]);
  useEffect(function () {
    var img = imageRef.current;
    if (img && img.complete && loading) handleLoad();
  }, [handleLoad, loading]);
  var classNames = cx(BASE_CLASS, "is-" + (loading ? 'loading' : 'loaded'), error && "is-error");
  var classNamesFigure = cx(BASE_CLASS_FIGURE, placeholder && CLASS_PLACEHOLDER, skeleton && CLASS_SKELETON);

  var handleError = function handleError() {
    setLoading(false);
    setError(true);
    onError && onError();
  };

  var figureStyles = {
    backgroundImage: "url(" + (placeholder || skeleton) + ")"
  };
  var SpinnerExtended = Spinner && React.cloneElement(Spinner, {
    className: CLASS_SPINNER
  });
  return /*#__PURE__*/React.createElement("div", {
    className: classNames
  }, /*#__PURE__*/React.createElement("figure", {
    className: classNamesFigure,
    style: !error && (placeholder || skeleton) ? figureStyles : {}
  }, /*#__PURE__*/React.createElement("img", Object.assign({
    className: CLASS_IMAGE,
    onLoad: handleLoad,
    onError: handleError,
    ref: imageRef
  }, imgProps))), !error && loading && SpinnerExtended, error && /*#__PURE__*/React.createElement(Error, {
    className: CLASS_ERROR,
    icon: errorIcon,
    text: errorText
  }));
};

AtomImage.displayName = 'AtomImage';
export default AtomImage;